==> limix_plot-0.1.0.tar.gz: limix_plot-0.1.0/limix_plot/qqplot.py <==
from __future__ import division
import numpy as np
import matplotlib.pylab as plt

class QQPlot(object):
    def __init__(self):
        self._pv = dict()
        self._gcontrol = dict()
        self._confidence_band = dict()
        self.plot_top = 100.

    def add(self, pv, label):
        self._pv[label] = np.asarray(pv)

    def set_confidence(self, tupl, label):
        self._confidence_band[label] = tupl

    def set_gcontrol(self, gc, label):
        self._gcontrol[label] = gc

    def plot(self, axis=None):
        axis = plt.gca() if axis is None else axis

        labels = self._pv.keys()
        for label in labels:
            self._plot_points(label, axis)

        psizes = [(k, len(v)) for (k, v) in self._pv.iteritems()]
        label = reduce(lambda a, b: a if a[1] > b[1] else b, psizes)[0]
        self._plot_confidence_band(label, 'black', axis)
        return axis

    def _plot_points(self, label, axis):
        lpv = -np.log10(self._pv[label])
        lpv.sort()

        lnpv = np.linspace(0, 1, len(lpv)+2)[1:-1]
        lnpv = -np.log10(lnpv)
        lnpv.sort()

        n = int(len(lnpv) * self.plot_top/100)

        axis.plot(lnpv[-n:], lpv[-n:], '.', label=label,
                  clip_on=False, zorder=100)

        axis.legend(loc='best')
        axis.set_ylabel('-log10(P) observed')
        axis.set_xlabel('-log10(P) expected')

    def _plot_confidence_band(self, label, color, axis):
        if label not in self._confidence_band:
            return

        (bo, me, to) = self._confidence_band[label]
        bo = -np.log(bo)
        me = -np.log(me)
        to = -np.log(to)
        x = y = me[0], me[-1]
        axis.plot(x, y, 'black')
        # n = int(len(me) * self.plot_top/100)
        axis.fill_between(me, bo, to, facecolor=color, alpha=0.2)

    def _get_full_label(self, label):
        if label in self._gcontrol:
            label += r' ($\\lambda_{\\mathrm{GC}}$=%.3f)' % self._gcontrol[label]
        return label

==> limix_plot-0.1.1.tar.gz: limix_plot-0.1.1/limix_plot/qqplot.py <==
from __future__ import division
import numpy as np
import matplotlib.pylab as plt

class QQPlot(object):
    def __init__(self):
        self._pv = dict()
        self._color = dict()
        self._gcontrol = dict()
        self._confidence_band = dict()
        self.plot_top = 100.

    def add(self, pv, label, color=None):
        self._pv[label] = np.asarray(pv)
        self._color[label] = color

    def set_confidence(self, tupl, label):
        self._confidence_band[label] = tupl

    def set_gcontrol(self, gc, label):
        self._gcontrol[label] = gc

    def plot(self, axis=None):
        axis = plt.gca() if axis is None else axis

        labels = self._pv.keys()
        for label in labels:
            self._plot_points(label, axis)

        psizes = [(k, len(v)) for (k, v) in self._pv.iteritems()]
        label = reduce(lambda a, b: a if a[1] > b[1] else b, psizes)[0]
        self._plot_confidence_band(label, 'black', axis)
        return axis

    def _plot_points(self, label, axis):
        lpv = -np.log10(self._pv[label])
        lpv.sort()

        lnpv = np.linspace(0, 1, len(lpv)+2)[1:-1]
        lnpv = -np.log10(lnpv)
        lnpv.sort()

        n = int(len(lnpv) * self.plot_top/100)

        rest = dict()
        if self._color[label]:
            rest['color'] = self._color[label]

        axis.plot(lnpv[-n:], lpv[-n:], '.', label=label,
                  clip_on=False, zorder=100, **rest)

        axis.legend(loc='best')
        axis.set_ylabel('-log10(P) observed')
        axis.set_xlabel('-log10(P) expected')

    def _plot_confidence_band(self, label, color, axis):
        if label not in self._confidence_band:
            return

        (bo, me, to) = self._confidence_band[label]
        bo = -np.log10(bo)
        me = -np.log10(me)
        to = -np.log10(to)
        x = y = me[0], me[-1]
        axis.plot(x, y, 'black')
        # n = int(len(me) * self.plot_top/100)
        axis.fill_between(me, bo, to, facecolor=color, alpha=0.2)

    def _get_full_label(self, label):
        if label in self._gcontrol:
            label += r' ($\\lambda_{\\mathrm{GC}}$=%.3f)' % self._gcontrol[label]
        return label
